@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20090411).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -29,7 +29,7 @@ static integer c_n24 = -24;
     static integer im1 = 255;
     static integer im2 = 65280;
     static integer im3 = 16711680;
-    static integer im4 = -16777216;
+    static integer im4 = 4278190080;
 
     /* System generated locals */
     integer i__1, i__2, i__3, i__4;
